==> netwosixwebadmin-0.0.1-src.tar.gz: netwosixwebadmin-0.0.1/src/libagent/agent.h <==
/**
 * WebAdmin
 * Copyright (C) 2006 Netwosix Team
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with this program; if not, write to the Free Software 
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * Linking WebAdmin statically or dynamically with other modules is making
 * a combined work based on WebAdmin. Thus, the terms and conditions of the 
 * GNU General Public License cover the whole combination.
 *
 * In addition, as a special exception, the copyright holders of
 * WebAdmin give you permission to combine WebAdmin with free software
 * programs or libraries that are released under the GNU LGPL and with
 * code included in the standard release of OpenSSL under the OpenSSL
 * License and SSLeay License (or modified versions of such code, with
 * unchanged licenses). You may copy and distribute such a system
 * following the terms of the GNU GPL for WebAdmin and the licenses of
 * the other code concerned, provided that you include the source code of
 * that other code when and as the GNU GPL requires distribution of
 * source code.
 *
 * Note that people who make modified versions of WebAdmin are not obligated
 * to grant this special exception for their modified versions; 
 * it is their choice whether to do so. The GNU General Public License 
 * gives permission to release a modified version without this exception; 
 * this exception also makes it possible to release a modified 
 * version which carries forward this exception.
 */

#ifndef AGENT_H
#define AGENT_H

#ifdef HAVE_CONFIG_H
#include "../config.h"
#endif

#include <al.h>

/**
 * Version
 */
#define AGENT_VERSION_MAJOR                 0
#define AGENT_VERSION_MINOR                 0
#define AGENT_VERSION_MICRO                 1
#define AGENT_VERSION_NAME           libagent

#define AGENT_VERSION              AL_TO_VERSION(AGENT_VERSION_NAME,AGENT_VERSION_MAJOR,AGENT_VERSION_MINOR,AGENT_VERSION_MICRO)


#include "request.h"
#include "response.h"


/**
 * Process the request packet from stdin e write the response packet 
 * to stdout.
 *
 * @param request_packet request packet who response is based
 * @param func func to call for every request
 *
 * @return 0 if ok
 */
int agent_main(int argc, char ** argv, agent_response_create_func func);


/**
 * A default main implementation tha call a func for every request.
 *
 * @param func func to call for process request
 * @param agent_name name of agent
 */
#define AGENT_DEFAULT_MAIN(agent_name,func)       \
  int main(int argc, char ** argv)                \
  {                                               \
	int ret;                                  \
	openlog(agent_name, LOG_PID, LOG_DAEMON); \
	ret = agent_main(argc, argv, &func);      \
	closelog();                               \
	return ret;                               \
  }


#endif /* AGENT_H */

==> netwosixwebadmin-0.0.2-src.tar.gz: netwosixwebadmin-0.0.2/src/libagent/agent.h <==
/**
 * WebAdmin
 * Copyright (C) 2006 Netwosix Team
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with this program; if not, write to the Free Software 
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * Linking WebAdmin statically or dynamically with other modules is making
 * a combined work based on WebAdmin. Thus, the terms and conditions of the 
 * GNU General Public License cover the whole combination.
 *
 * In addition, as a special exception, the copyright holders of
 * WebAdmin give you permission to combine WebAdmin with free software
 * programs or libraries that are released under the GNU LGPL and with
 * code included in the standard release of OpenSSL under the OpenSSL
 * License and SSLeay License (or modified versions of such code, with
 * unchanged licenses). You may copy and distribute such a system
 * following the terms of the GNU GPL for WebAdmin and the licenses of
 * the other code concerned, provided that you include the source code of
 * that other code when and as the GNU GPL requires distribution of
 * source code.
 *
 * Note that people who make modified versions of WebAdmin are not obligated
 * to grant this special exception for their modified versions; 
 * it is their choice whether to do so. The GNU General Public License 
 * gives permission to release a modified version without this exception; 
 * this exception also makes it possible to release a modified 
 * version which carries forward this exception.
 */

#ifndef AGENT_H
#define AGENT_H

#ifdef HAVE_CONFIG_H
#include "../config.h"
#endif

#include <al.h>

/**
 * Version
 */
#define LIB_AGENT_VERSION_MAJOR                 0
#define LIB_AGENT_VERSION_MINOR                 0
#define LIB_AGENT_VERSION_MICRO                 2
#define LIB_AGENT_VERSION_NAME           libagent

#define LIB_AGENT_VERSION                AL_TO_VERSION(LIB_AGENT_VERSION_NAME, \
						       LIB_AGENT_VERSION_MAJOR,\
						       LIB_AGENT_VERSION_MINOR,\
						       LIB_AGENT_VERSION_MICRO)


#include "agent-request.h"
#include "agent-response.h"


/**
 * Process the request packet from stdin e write the response packet 
 * to stdout.
 *
 * @param request_packet request packet who response is based
 * @param func func to call for every request
 *
 * @return 0 if ok
 */
int agent_main(int argc, char ** argv, agent_response_create_func func);

/**
 * Return the parameter passed to the main.
 *
 * @retval argc arg count
 *
 * @return argv
 */
char ** agent_get_args(int * argc);
 

/**
 * A default main implementation tha call a func for every request.
 *
 * @param func func to call for process request
 * @param agent_name name of agent
 */
#define AGENT_DEFAULT_MAIN(agent_name,func)       \
  int main(int argc, char ** argv)                \
  {                                               \
	int ret;                                  \
	openlog(agent_name, LOG_PID, LOG_DAEMON); \
	ret = agent_main(argc, argv, &func);      \
	closelog();                               \
	return ret;                               \
  }


#endif /* AGENT_H */
